==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/networkfirewall/kotlin/inputs/RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.networkfirewall.kotlin.inputs

import com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property definitions Set of IP addresses and address ranges, in CIDR notation.
 */
public data class RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs(
    public val definitions: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs> {
    override fun toJava():
        com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs =
        com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs.builder()
            .definitions(definitions.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleGroupRuleVariablesIpSetIpSetArgsBuilder internal constructor() {
    private var definitions: Output<List<String>>? = null

    /**
     * @param value Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("dbqqngovwctosajr")
    public suspend fun definitions(`value`: Output<List<String>>) {
        this.definitions = value
    }

    @JvmName("lskjdeceknjnloll")
    public suspend fun definitions(vararg values: Output<String>) {
        this.definitions = Output.all(values.asList())
    }

    /**
     * @param values Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("heleuaafouelkien")
    public suspend fun definitions(values: List<Output<String>>) {
        this.definitions = Output.all(values)
    }

    /**
     * @param value Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("mreoudtxnmsohhcy")
    public suspend fun definitions(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.definitions = mapped
    }

    /**
     * @param values Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("prgvbgiyjgnpbbqk")
    public suspend fun definitions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.definitions = mapped
    }

    internal fun build(): RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs =
        RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs(
            definitions = definitions ?: throw PulumiNullFieldException("definitions"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/networkfirewall/kotlin/inputs/RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.networkfirewall.kotlin.inputs

import com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property definitions Set of IP addresses and address ranges, in CIDR notation.
 */
public data class RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs(
    public val definitions: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs> {
    override fun toJava(): com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs =
        com.pulumi.aws.networkfirewall.inputs.RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs.builder()
            .definitions(definitions.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleGroupRuleVariablesIpSetIpSetArgsBuilder internal constructor() {
    private var definitions: Output<List<String>>? = null

    /**
     * @param value Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("voqusuhocxwnewpj")
    public suspend fun definitions(`value`: Output<List<String>>) {
        this.definitions = value
    }

    @JvmName("vynlelfcagtguede")
    public suspend fun definitions(vararg values: Output<String>) {
        this.definitions = Output.all(values.asList())
    }

    /**
     * @param values Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("gonpqvirqbjjablq")
    public suspend fun definitions(values: List<Output<String>>) {
        this.definitions = Output.all(values)
    }

    /**
     * @param value Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("fkqukhisnduurlyr")
    public suspend fun definitions(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.definitions = mapped
    }

    /**
     * @param values Set of IP addresses and address ranges, in CIDR notation.
     */
    @JvmName("ayxqqqynsilsiqnf")
    public suspend fun definitions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.definitions = mapped
    }

    internal fun build(): RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs =
        RuleGroupRuleGroupRuleVariablesIpSetIpSetArgs(
            definitions = definitions ?: throw PulumiNullFieldException("definitions"),
        )
}
